Toddy.Iced.FilterMethod (Toddy v0.3.0)

Copy Markdown View Source

Interpolation mode for the image filter_method prop.

Maps to iced's image::FilterMethod enum.

Summary

Functions

Encodes a filter method value to the wire format.

Types

t()

@type t() :: :nearest | :linear

Functions

encode(value)

@spec encode(filter_method :: t()) :: String.t()

Encodes a filter method value to the wire format.

Examples

iex> Toddy.Iced.FilterMethod.encode(:nearest)
"nearest"

iex> Toddy.Iced.FilterMethod.encode(:linear)
"linear"