Interpolation mode for the image filter_method prop.
Maps to iced's image::FilterMethod enum.
Summary
Functions
Encodes a filter method value to the wire format.
Interpolation mode for the image filter_method prop.
Maps to iced's image::FilterMethod enum.
Encodes a filter method value to the wire format.