Pin layout -- positions child at absolute coordinates.
Props
x(number) -- x position in pixels. Default: 0.y(number) -- y position in pixels. Default: 0.width(length) -- pin container width. Default: shrink. SeeToddy.Iced.Length.height(length) -- pin container height. Default: shrink.a11y(map) -- accessibility overrides. SeeToddy.Iced.A11y.
Summary
Functions
Sets accessibility annotations.
Converts this pin struct to a ui_node() map via the Toddy.Iced.Widget protocol.
Appends multiple children to the pin.
Sets the pin container height.
Creates a new pin struct with optional keyword opts.
Appends a child to the pin.
Sets the pin container width.
Applies keyword options to an existing pin struct.
Sets the x position in pixels.
Sets the y position in pixels.
Types
@type option() :: {:x, number()} | {:y, number()} | {:width, Toddy.Iced.Length.t()} | {:height, Toddy.Iced.Length.t()} | {:a11y, Toddy.Iced.A11y.t()}
@type t() :: %Toddy.Iced.Widget.Pin{ a11y: Toddy.Iced.A11y.t() | nil, children: [Toddy.Iced.ui_node() | struct()], height: Toddy.Iced.Length.t() | nil, id: String.t(), width: Toddy.Iced.Length.t() | nil, x: number() | nil, y: number() | nil }
Functions
@spec a11y(pin :: t(), a11y :: Toddy.Iced.A11y.t()) :: t()
Sets accessibility annotations.
@spec build(pin :: t()) :: Toddy.Iced.ui_node()
Converts this pin struct to a ui_node() map via the Toddy.Iced.Widget protocol.
@spec extend(pin :: t(), children :: [Toddy.Iced.ui_node() | struct()]) :: t()
Appends multiple children to the pin.
@spec height(pin :: t(), height :: Toddy.Iced.Length.t()) :: t()
Sets the pin container height.
Creates a new pin struct with optional keyword opts.
@spec push(pin :: t(), child :: Toddy.Iced.ui_node() | struct()) :: t()
Appends a child to the pin.
@spec width(pin :: t(), width :: Toddy.Iced.Length.t()) :: t()
Sets the pin container width.
Applies keyword options to an existing pin struct.
Sets the x position in pixels.
Sets the y position in pixels.