Empty space -- invisible spacer widget.
Props
width(length) -- space width. Default: shrink. SeeToddy.Iced.Length.height(length) -- space height. Default: shrink.a11y(map) -- accessibility overrides. SeeToddy.Iced.A11y.
Summary
Functions
Sets accessibility annotations.
Converts this space struct to a ui_node() map via the Toddy.Iced.Widget protocol.
Sets the space height.
Creates a new space struct with optional keyword opts.
Sets the space width.
Applies keyword options to an existing space struct.
Types
@type option() :: {:width, Toddy.Iced.Length.t()} | {:height, Toddy.Iced.Length.t()} | {:a11y, Toddy.Iced.A11y.t()}
@type t() :: %Toddy.Iced.Widget.Space{ a11y: Toddy.Iced.A11y.t() | nil, height: Toddy.Iced.Length.t() | nil, id: String.t(), width: Toddy.Iced.Length.t() | nil }
Functions
@spec a11y(space :: t(), a11y :: Toddy.Iced.A11y.t()) :: t()
Sets accessibility annotations.
@spec build(space :: t()) :: Toddy.Iced.ui_node()
Converts this space struct to a ui_node() map via the Toddy.Iced.Widget protocol.
@spec height(space :: t(), height :: Toddy.Iced.Length.t()) :: t()
Sets the space height.
Creates a new space struct with optional keyword opts.
@spec width(space :: t(), width :: Toddy.Iced.Length.t()) :: t()
Sets the space width.
Applies keyword options to an existing space struct.