Per-subtree theme override -- applies a different theme to child widgets.
Props
theme-- a built-in theme atom (e.g.:dark,:nord) or a custom palette map. SeeToddy.Iced.Theme.a11y(map) -- accessibility overrides. SeeToddy.Iced.A11y.
Summary
Functions
Sets accessibility annotations.
Converts this themer struct to a ui_node() map via the Toddy.Iced.Widget protocol.
Appends multiple children to the themer.
Creates a new themer struct with the given theme.
Appends a child to the themer.
Types
@type t() :: %Toddy.Iced.Widget.Themer{ a11y: Toddy.Iced.A11y.t() | nil, children: [Toddy.Iced.ui_node() | struct()], id: String.t(), theme: Toddy.Iced.Theme.t() }
Functions
@spec a11y(themer :: t(), a11y :: Toddy.Iced.A11y.t()) :: t()
Sets accessibility annotations.
@spec build(themer :: t()) :: Toddy.Iced.ui_node()
Converts this themer struct to a ui_node() map via the Toddy.Iced.Widget protocol.
@spec extend(themer :: t(), children :: [Toddy.Iced.ui_node() | struct()]) :: t()
Appends multiple children to the themer.
@spec new(id :: String.t(), theme :: Toddy.Iced.Theme.t()) :: t()
Creates a new themer struct with the given theme.
@spec push(themer :: t(), child :: Toddy.Iced.ui_node() | struct()) :: t()
Appends a child to the themer.